@@ -1,6 +1,7 @@
 """
-Copyright (c) 2021 by Benjamin Manns
 This file is part of the Semantic Quality Benchmark for Word Embeddings Tool in Python (SeaQuBe).
+
+Copyright (c) 2021 by Benjamin Manns
 :author: Benjamin Manns
 """
 
@@ -25,6 +26,7 @@ class C2VWV:
     def __init__(self, word2index: dict, vocabs: list, matrix):
         self.matrix = matrix
         self.word2index = word2index
+        self.index2word = vocabs  # should be same as vocabs variable
         self.vectors = matrix
         self.vocabs = vocabs
 
@@ -75,7 +77,7 @@ class Context2Vec:
             self.reader.open()
             for sent in self.reader.next_batch():
 
-                self.backend_model.zerograds()
+                self.backend_model.cleargrads()
                 loss = self.backend_model(sent)
                 accum_loss += loss.data
                 loss.backward()
